@@ -4,7 +4,6 @@ import click
 import sys
 from .. import __version__
 
-
 # Monkey patch
 click.core._verify_python3_env = lambda: None
 
@@ -16,17 +15,9 @@ CONTEXT_SETTINGS = {
 
 @click.version_option(__version__, "-V", "--version")
 @click.group(context_settings=CONTEXT_SETTINGS)
+@click.option("-v", "--verbose", help="Verbose logging", is_flag=True, default=False)
 @click.option(
-    "-v", "--verbose",
-    help="Verbose logging",
-    is_flag=True,
-    default=False
-)
-@click.option(
-    "-d", "--debug",
-    help="Post mortem debugging",
-    is_flag=True,
-    default=False
+    "-d", "--debug", help="Post mortem debugging", is_flag=True, default=False
 )
 def cli(verbose, debug):
     """
@@ -54,13 +45,14 @@ def cli(verbose, debug):
 
 
 from . import (
-    dump_cworld,
-    diamond_insulation,
-    compute_expected,
-    logbin_expected,
-    compute_saddle,
-    call_dots,
-    call_compartments,
+    expected_cis,
+    expected_trans,
+    insulation,
+    pileup,
+    eigs_cis,
+    eigs_trans,
+    saddle,
+    dots,
     genome,
-    random_sample,
+    sample,
 )
