@@ -2,8 +2,7 @@ import warnings
 from scipy.linalg import toeplitz
 import scipy.sparse.linalg
 import scipy.interpolate
-from scipy.ndimage.interpolation import zoom
-import scipy.ndimage.filters
+from scipy.ndimage import zoom, gaussian_filter1d
 import numpy as np
 import numba
 import cooler
@@ -25,7 +24,8 @@ def get_diag(arr, i=0):
     """
     return arr.ravel()[
         max(i, -arr.shape[1] * i) : max(0, (arr.shape[1] - i))
-        * arr.shape[1] : arr.shape[1] + 1
+        * arr.shape[1] : arr.shape[1]
+        + 1
     ]
 
 
@@ -495,7 +495,7 @@ def get_eig(mat, n=3, mask_zero_rows=False, subtract_mean=False, divide_by_mean=
 
         return eigvecs, eigvals
     else:
-        mat = mat.astype(np.float, copy=True)  # make a copy, ensure float
+        mat = mat.astype(np.float64, copy=True)  # make a copy, ensure float
 
         # prepare NaN-filled arrays for output in case we requested
         # more eigenvalues that can be computed (eigs/eigsh k limits)
@@ -521,7 +521,7 @@ def get_eig(mat, n=3, mask_zero_rows=False, subtract_mean=False, divide_by_mean=
         # reorder according to eigvals and copy into output arrays
         order = np.argsort(-np.abs(_eigvals))
         eigvals[:_n] = _eigvals[order]
-        eigvecs[:_n,:] = _eigvecs.T[order]
+        eigvecs[:_n, :] = _eigvecs.T[order]
 
         return eigvecs, eigvals
 
@@ -667,6 +667,15 @@ def iterative_correction_symmetric(
     tol : float
         If less or equal to zero, will perform max_iter iterations.
 
+    Returns
+    -------
+    _x : np.ndarray
+        Corrected matrix
+    totalBias : np.ndarray
+        Vector with corrections biases
+    report : (bool, int)
+        A tuple that reports convergence
+        status and used number of iterations
     """
     N = len(x)
 
@@ -709,7 +718,7 @@ def iterative_correction_symmetric(
     corr = totalBias[~mask].mean()  # mean correction factor
     _x = _x * corr * corr  # renormalizing everything
     totalBias /= corr
-    report = {"converged": converged, "iternum": iternum}
+    report = (converged, iternum)
 
     return _x, totalBias, report
 
@@ -728,6 +737,18 @@ def iterative_correction_asymmetric(x, max_iter=1000, tol=1e-5, verbose=False):
         The number of diagonals to ignore during iterative correction.
     tol : float
         If less or equal to zero, will perform max_iter iterations.
+
+    Returns
+    -------
+    _x : np.ndarray
+        Corrected matrix
+    totalBias : np.ndarray
+        Vector with corrections biases for columns
+    totalBias2 : np.ndarray
+        Vector with corrections biases for rows
+    report : (bool, int)
+        A tuple that reports convergence
+        status and used number of iterations
     """
     N2, N = x.shape
     _x = x.copy()
@@ -776,7 +797,7 @@ def iterative_correction_asymmetric(x, max_iter=1000, tol=1e-5, verbose=False):
     _x = _x * corr * corr2  # renormalizing everything
     totalBias /= corr
     totalBias2 /= corr2
-    report = {"converged": converged, "iternum": iternum}
+    report = (converged, iternum)
 
     return _x, totalBias, totalBias2, report
 
@@ -854,7 +875,7 @@ def get_kernel(w, p, ktype):
 
     """
     width = 2 * w + 1
-    kernel = np.ones((width, width), dtype=np.int)
+    kernel = np.ones((width, width), dtype=np.int64)
     # mesh grid:
     y, x = np.ogrid[-w : w + 1, -w : w + 1]
 
@@ -1379,10 +1400,7 @@ def adaptive_coarsegrain(ar, countar, cutoff=5, max_levels=8, min_shape=8):
 
 
 def robust_gauss_filter(
-    ar,
-    sigma=2,
-    functon=scipy.ndimage.filters.gaussian_filter1d,
-    kwargs=None
+    ar, sigma=2, functon=gaussian_filter1d, kwargs=None
 ):
     """
     Implements an edge-handling mode for gaussian filter that basically ignores
@@ -1431,7 +1449,7 @@ def robust_gauss_filter(
     mask = np.isfinite(ar)
     ar[~mask] = 0
     a = functon(ar, sigma=sigma, mode="constant", **kwargs)
-    b = functon(1. * mask, sigma=sigma, mode="constant", **kwargs)
+    b = functon(1.0 * mask, sigma=sigma, mode="constant", **kwargs)
     return a / b
 
 
@@ -1456,23 +1474,29 @@ def weighted_groupby_mean(df, group_by, weigh_by, mode="mean"):
         group_by = [group_by]
     gr = df.groupby(group_by)
     if mode == "mean":
+
         def wstd(x):
             return np.average(x, weights=df.loc[x.index, weigh_by])
+
         wm = wstd
     elif mode == "std":
+
         def wstd(x):
             wm = np.average(x, weights=df.loc[x.index, weigh_by])
             dev = x - wm
-            res = np.sqrt(np.average(dev**2, weights=df.loc[x.index, weigh_by]))
+            res = np.sqrt(np.average(dev ** 2, weights=df.loc[x.index, weigh_by]))
             return res
+
         wm = wstd
     elif mode == "logstd":
+
         def wstd(x):
             x = np.log(x)
             wm = np.average(x, weights=df.loc[x.index, weigh_by])
             dev = x - wm
-            res = np.sqrt(np.average(dev**2, weights=df.loc[x.index, weigh_by]))
+            res = np.sqrt(np.average(dev ** 2, weights=df.loc[x.index, weigh_by]))
             return np.exp(res)
+
         wm = wstd
     else:
         raise NotImplementedError
@@ -1482,7 +1506,7 @@ def weighted_groupby_mean(df, group_by, weigh_by, mode="mean"):
         if i in group_by:
             continue
         elif i == weigh_by:
-            f[i] = ['sum']
+            f[i] = ["sum"]
         else:
             f[i] = [wm]
     agg = gr.agg(f)
@@ -1548,6 +1572,8 @@ def persistent_log_bins(end=10, bins_per_order_magnitude=10):
         raise ValueError("End is a log10(max_value), not the max_value itself")
     bin_float = np.logspace(0, end, end * bins_per_order_magnitude + 1)
     bin_int = np.array(np.rint(bin_float), dtype=int)  # rounding to the nearest int
-    bins = np.unique(bin_int)   # unique bins
-    bins = np.cumsum(np.sort(np.r_[1, np.diff(bins)]))  # re-ordering gaps (important step)
+    bins = np.unique(bin_int)  # unique bins
+    bins = np.cumsum(
+        np.sort(np.r_[1, np.diff(bins)])
+    )  # re-ordering gaps (important step)
     return bins
